==> aiogram-newsletter-0.0.1.tar.gz: aiogram-newsletter-0.0.1/README.md <==
# 📦 aiogram Newsletter Handler

[![PyPI](https://img.shields.io/pypi/v/aiogram-newsletter.svg?color=FFE873&labelColor=3776AB)](https://pypi.python.org/pypi/aiogram-newsletter)
![Python Versions](https://img.shields.io/badge/Python-3.8%20--%203.12-black?color=FFE873&labelColor=3776AB)
[![License](https://img.shields.io/github/license/nessshon/aiogram-newsletter)](https://github.com/nessshon/aiogram-newsletter/blob/main/LICENSE)

![Downloads](https://pepy.tech/badge/aiogram-newsletter)
![Downloads](https://pepy.tech/badge/aiogram-newsletter/month)
![Downloads](https://pepy.tech/badge/aiogram-newsletter/week)

* Bot example: [@aiogramNewsletterBot](https://t.me/aiogramNewsletterBot/).
* Code example: [source code](https://github.com/nessshon/aiogram-newsletter/example)

## Installation

```bach
pip install aiogram-newsletter
```

## Usage

* Coming soon...

## Features

* Ready-to-Use User Interface
* Middleware Functionality
* Interface Customization
* Multilingual Support

## Acknowledgments

This project utilizes the following dependencies to enhance its functionality:

- [**aiogram:**](https://pypi.org/project/aiogram/) An asynchronous framework for building Telegram bots.
- [**APScheduler:**](https://pypi.org/project/APScheduler/) In-process task scheduler with Cron-like capabilities.

We extend our gratitude to the maintainers and contributors of these libraries for their valuable contributions to the
open-source community.

## Contribution

We welcome your contributions! If you have ideas for improvement or have identified a bug, please create an issue or
submit a pull request.

## Donations

**TON** - `EQC-3ilVr-W0Uc3pLrGJElwSaFxvhXXfkiQA3EwdVBHNNess`

**USDT** (TRC-20) - `TJjADKFT2i7jqNJAxkgeRm5o9uarcoLUeR`

## License

This repository is distributed under
the [MIT License](https://github.com/nessshon/aiogram-newsletter/blob/main/LICENSE). Feel free to use, modify, and
distribute the code in accordance with the terms of the license.

==> aiogram-newsletter-0.0.10.tar.gz: aiogram-newsletter-0.0.10/README.md <==
# 📦 aiogram Newsletter Handler

[![PyPI](https://img.shields.io/pypi/v/aiogram-newsletter.svg?color=FFE873&labelColor=3776AB)](https://pypi.python.org/pypi/aiogram-newsletter)
![Python Versions](https://img.shields.io/badge/Python-3.8%20--%203.12-black?color=FFE873&labelColor=3776AB)
[![License](https://img.shields.io/github/license/nessshon/aiogram-newsletter)](https://github.com/nessshon/aiogram-newsletter/blob/main/LICENSE)

![Downloads](https://pepy.tech/badge/aiogram-newsletter)
![Downloads](https://pepy.tech/badge/aiogram-newsletter/month)
![Downloads](https://pepy.tech/badge/aiogram-newsletter/week)

* Bot example: [@aiogramNewsletterBot](https://t.me/aiogramNewsletterBot/).
* Code example: [source code](https://github.com/nessshon/aiogram-newsletter/tree/main/example)

## Installation

```bach
pip install aiogram-newsletter
```

## Usage

* Coming soon...

## Features

* Ready-to-Use User Interface
* Middleware Functionality
* Interface Customization
* Multilingual Support

## Acknowledgments

This project utilizes the following dependencies to enhance its functionality:

- [**aiogram:**](https://pypi.org/project/aiogram/) An asynchronous framework for building Telegram bots.
- [**APScheduler:**](https://pypi.org/project/APScheduler/) In-process task scheduler with Cron-like capabilities.

We extend our gratitude to the maintainers and contributors of these libraries for their valuable contributions to the
open-source community.

## Contribution

We welcome your contributions! If you have ideas for improvement or have identified a bug, please create an issue or
submit a pull request.

## Donations

**TON** - `EQC-3ilVr-W0Uc3pLrGJElwSaFxvhXXfkiQA3EwdVBHNNess`

**USDT** (TRC-20) - `TJjADKFT2i7jqNJAxkgeRm5o9uarcoLUeR`

## License

This repository is distributed under
the [MIT License](https://github.com/nessshon/aiogram-newsletter/blob/main/LICENSE). Feel free to use, modify, and
distribute the code in accordance with the terms of the license.
